@@ -4,7 +4,7 @@ from rest_framework.viewsets import ModelViewSet
 from rest_framework.generics import ListAPIView
 from rest_framework.response import Response
 from .func import get_tree
-from .jwt_token import jwt_get_userid_handler, jwt_get_openid_handler, jwt_get_unionid_handler
+from .jwt_token import jwt_get_userinfo_handler
 
 
 class CustomModelViewSet(ModelViewSet):
@@ -16,10 +16,9 @@ class CustomModelViewSet(ModelViewSet):
 
 
 def user_perform_create(token, serializer):
-    user_id = jwt_get_userid_handler(token)
-    openid = jwt_get_openid_handler(token)
-    unionid = jwt_get_unionid_handler(token)
-    serializer.save(user_id=user_id, openid=openid, unionid=unionid)
+    user_id, openid, unionid, wechat_id = jwt_get_userinfo_handler(token)
+    serializer.save(user_id=user_id, openid=openid,
+                    unionid=unionid, wechat_id=wechat_id)
 
 
 class TreeAPIView(ListAPIView):
