@@ -9,9 +9,11 @@ from rest_framework.permissions import IsAuthenticatedOrReadOnly
 from rest_framework.response import Response
 from wechatpy import parse_message, create_reply, utils
 from bluedot_rest_framework.utils.jwt_token import jwt_create_token_wechat
+from bluedot_rest_framework.settings import api_settings
+from django.utils.module_loading import import_string
 from . import MiniProgram, OfficialAccount, WXBizDataCrypt, official_account_oauth
-
 from .models import WeChatUser
+User = import_string(api_settings.USER['models'])
 
 
 class JSSdk(APIView):
@@ -109,12 +111,16 @@ class OAuth(APIView):
             wechat_queryset = WeChatUser.objects.filter(
                 openid=user_info['openid']).first()
             if wechat_queryset:
-                wechat_queryset.update(**user_data)
+                wechat_queryset.save(**user_data)
             else:
                 wechat_queryset = WeChatUser.objects.create(**user_data)
-
+            user_id = 0
+            user_queryset = User.objects.filter(
+                wechat_id=wechat_queryset.pk).first()
+            if user_queryset:
+                user_id = user_queryset.pk
             token = jwt_create_token_wechat(
-                openid=wechat_queryset.openid, unionid=wechat_queryset.unionid, wechat_id=wechat_queryset.pk)
+                openid=wechat_queryset.openid, unionid=wechat_queryset.unionid, userid=user_id, wechat_id=wechat_queryset.pk)
             link_type = '?'
             if "?" in referer_uri:
                 link_type = '&'
